==> Products.BastionLedger-4.6.0.tar.gz: Products.BastionLedger-4.6.0/Products/BastionLedger/interfaces/tools.py <==
#
#    Copyright (C) 2009-2013  Corporation of Balclutha. All rights Reserved.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
#    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#    IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
#    ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
#    LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
#    CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
#    GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
#    HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
#    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
#    OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

from zope.interface import Interface

class ILedgerControllerTool(Interface):
    """
    A site-wide controller of ledgers
    """

class IBLLedgerTool(Interface):
    """
    marker for a Ledger Tool, and thus something droppable into a Ledger
    """

class IBLLedgerToolMultiple(Interface):
    """
    marker for a Ledger Tool, and thus something droppable into a Ledger of which
    there may be more than one
    """

class IBLControllerTool(Interface):
    """
    marker for a Ledger Controller Tool, and thus something droppable into a portal_bastionledger
    """

class IBLControllerToolMultiple(Interface):
    """
    marker for a Ledger Controller Tool, and thus something droppable into a portal_bastionledger of which
    there may be more than one
    """

==> Products.BastionLedger-4.6.5.tar.gz: Products.BastionLedger-4.6.5/Products/BastionLedger/interfaces/tools.py <==
#
#    Copyright (C) 2009-2013  Corporation of Balclutha. All rights Reserved.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
#    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#    IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
#    ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
#    LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
#    CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
#    GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
#    HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
#    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
#    OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

from zope.interface import Interface
from plone.uuid.interfaces import IAttributeUUID

class ILedgerControllerTool(Interface):
    """
    A site-wide controller of ledgers
    """

class IBLLedgerTool(IAttributeUUID):
    """
    marker for a Ledger Tool, and thus something droppable into a Ledger
    """

class IBLLedgerToolMultiple(IAttributeUUID):
    """
    marker for a Ledger Tool, and thus something droppable into a Ledger of which
    there may be more than one
    """

class IBLControllerTool(Interface):
    """
    marker for a Ledger Controller Tool, and thus something droppable into a portal_bastionledger
    """

class IBLControllerToolMultiple(Interface):
    """
    marker for a Ledger Controller Tool, and thus something droppable into a portal_bastionledger of which
    there may be more than one
    """
